@@ -1,11 +1,13 @@
-/* $Id: platform.h,v 1.4 2005/10/21 14:58:43 dijkstra Exp $ */
+/* $Id: platform.h,v 1.6 2007/02/11 20:07:31 dijkstra Exp $ */
 
 #ifndef _CONF_FREEBSD_H
 #define _CONF_FREEBSD_H
 
 #include <sys/queue.h>
-#include <sys/socket.h>
 #include <sys/types.h>
+#include <sys/socket.h>
+#include <sys/time.h>
+#include <sys/dkstat.h>
 #include <sys/resource.h>
 
 #include <net/if.h>
@@ -20,13 +22,13 @@
 
 union stream_parg {
     struct {
-	long time[CPUSTATES];
-	long old[CPUSTATES];
-	long diff[CPUSTATES];
-	int states[CPUSTATES];
+        long time[CPUSTATES];
+        long old[CPUSTATES];
+        long diff[CPUSTATES];
+        int states[CPUSTATES];
     } cp;
     struct {
-	char rawdev[SYMON_DFNAMESIZE];
+        char rawdev[SYMON_DFNAMESIZE];
     } df;
     struct ifreq ifr;
     int sn;
